#
# spec file for package perl-Contextual-Return
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Contextual-Return
Version:        0.004014
Release:        1.29
%define cpan_name Contextual-Return
Summary:        Create context-sensitive return values
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Contextual-Return/
Source0:        https://cpan.metacpan.org/authors/id/D/DC/DCONWAY/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Want)
BuildRequires:  perl(version)
Requires:       perl(Want)
Requires:       perl(version)
%{perl_requires}

%description
Usually, when you need to create a subroutine that returns different values
in different contexts (list, scalar, or void), you write something like:

    sub get_server_status {
        my ($server_ID) = @_;

        # Acquire server data somehow...
        my %server_data = _ascertain_server_status($server_ID);

        # Return different components of that data,
        # depending on call context...
        if (wantarray()) {
            return @server_data{ qw(name uptime load users) };
        }
        if (defined wantarray()) {
            return $server_data{load};
        }
        if (!defined wantarray()) {
            carp 'Useless use of get_server_status() in void context';
            return;
        }
        else {
            croak q{Bad context! No biscuit!};
        }
    }

That works okay, but the code could certainly be more readable. In its
simplest usage, this module makes that code more readable by providing
three subroutines--'LIST()', 'SCALAR()', 'VOID()'--that are true only when
the current subroutine is called in the corresponding context:

    use Contextual::Return;

    sub get_server_status {
        my ($server_ID) = @_;

        # Acquire server data somehow...
        my %server_data = _ascertain_server_status($server_ID);

        # Return different components of that data
        # depending on call context...
        if (LIST)   { return @server_data{ qw(name uptime load users) } }
        if (SCALAR) { return $server_data{load}                         }
        if (VOID)   { print "$server_data{load}\n"                      }
        else        { croak q{Bad context! No biscuit!}                 }
    }

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README

%changelog
* Wed Apr 19 2017 coolo@suse.com
- updated to 0.004014
  see /usr/share/doc/packages/perl-Contextual-Return/Changes
* Thu Apr 13 2017 coolo@suse.com
- updated to 0.004012
  see /usr/share/doc/packages/perl-Contextual-Return/Changes
  0.004012  Thu Apr 13 01:06:09 2017
  - Optimized previous patch for memory leak
    (thanks, Jay and Father C.)
  - Added missing test plan to t/fail.t
* Sun Apr  9 2017 coolo@suse.com
- updated to 0.004011
  see /usr/share/doc/packages/perl-Contextual-Return/Changes
  0.004011  Sat Apr  8 15:23:14 2017
  - Patched memory leak from use of @DB::args
    (thanks, Jay!)
* Fri Dec  2 2016 coolo@suse.com
- updated to 0.004010
  see /usr/share/doc/packages/perl-Contextual-Return/Changes
  0.004010  Thu Dec  1 17:41:14 2016
  - Spelling fix in POD (thanks, Salvatore)
  - Improved DUMP behaviour when passed a non-CRV argument
    (thanks, Mathew)
* Wed Nov 23 2016 coolo@suse.com
- remove Build.PL, it's obsolete
* Fri Nov 18 2016 coolo@suse.com
- updated to 0.004009
  see /usr/share/doc/packages/perl-Contextual-Return/Changes
  0.004009  Fri Nov 18 08:34:19 2016
  - Improved behaviour of FREEZE (Thanks, Mathew!)
  - Improved output of DUMP
* Mon Sep 14 2015 coolo@suse.com
- updated to 0.004008
  see /usr/share/doc/packages/perl-Contextual-Return/Changes
  0.004008  Sat Sep 12 13:16:30 2015
  - Promoted $VERSION variable to earlier in source to
    attempt to placate cpanminus (thanks, Karen!)
  - Added prototype to overridden caller()
  - Changed way caller() is overridden, hopefully will no longer
    clash with Sub::Uplevel
* Mon Dec 17 2012 dvaleev@suse.com
- update to 0.004007
  - Further patch to failures.t
  - Added redefinition of Scalar::Util::blessed() to avoid nasty
    surprises (thanks Andrew!)
  - Added confess() and cluck() overrides
    and fixed caller() override to set @DB::args when appropriate
  - Further patch for t/confess.t
    (Thanks, David!)
  - Circumvented annoying undef-as-key warnings in Perl 5.17+
  - Honour @CARP_NOT's when reporting context
  - Added BLESSED handler for better control over how blessed() lies
  - Upgraded reimplementation of blessed() to make more sense
- reanable tests for ARM (fixed upstream)
- fix ppc test failures
- provide Build.PL to be able to use create_packlist=0
* Wed Aug  8 2012 dmueller@suse.com
- also fails on native, fix build on ARM
* Thu Jul 26 2012 dmueller@suse.com
- workaround build failure under qemu user emulation
* Wed May 30 2012 coolo@suse.com
- updated to 0.004003
  - Doc patch (thanks Fabrizio)
  - Patched failures.t to account from bleadperl changes
    (thanks Zefram!)
* Tue Mar  6 2012 coolo@suse.com
- updated to 0.004002
  Fixed significant typo (Carp:carp -> Carp::carp)
    (thanks everyone who reported it)
* Mon Feb 27 2012 coolo@suse.com
- updated to 0.004001
  - Updated version number of Contextual::Return::Failure
    to placate CPAN indexer
  - Improved error messages for bare handlers in bad contexts (thanks Mathew)
  - Work around problems with Test::More and caller
  - Fixed context propagation bugs in FIXED and ACTIVE modifiers
  - Added STRICT modifier to prevent fallbacks
    (i.e. impose strict typing on return values)
  - Fixed annoying POD nit (thanks Salvatore)
* Tue Jul 19 2011 coolo@novell.com
- regenerate with cpanspec
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Nov 19 2010 pascal.bleser@opensuse.org
- initial package (0.003001)
